@@ -130,6 +130,15 @@ def generate_config(polled):
     if services:
         global_config["services"] = services
 
+    if "artifacts" in polled:
+        job_config["artifacts"] = {}
+        for item in polled["artifacts"]:
+            for element in ["name", "when", "paths", "reports", "expire_in"]:
+                if element in item:
+                    value = item.get(element)
+                    if value is not None:
+                        job_config["artifacts"][element] = value
+
     for step in polled["steps"]:
         job_config[step["name"]] = step["script"]
 
