@@ -182,6 +182,7 @@ def run(runner, job, docker):
     from gitlabemu import errors
 
     trace = TraceProxy(runner, job)
+    derived_config = False
 
     logmsg.FATAL_EXIT = False
 
@@ -225,9 +226,12 @@ def run(runner, job, docker):
                 for line in new_config_fh:
                     trace.writeline("#" + line)
             end_log_section(trace, "child-job")
+            derived_config = True
         # load the config
         ci_file = os.path.join(build_dir_abs, ci_cfg)
         config = configloader.read(ci_file)
+        if derived_config:
+            config["_workspace"] = build_dir_abs
 
         # populate real vars
         for var in job["variables"]:
