@@ -77,7 +77,7 @@ class Runner(Session):
 
         resp.raise_for_status()
 
-        result = resp.json()
+        result = self.json(resp)
 
         self.token = result.get("token", None)
 
@@ -136,7 +136,7 @@ class Runner(Session):
 
         if resp.status_code == 201:
             # we have been given a job!
-            return resp.json()
+            return self.json(resp)
 
         return None
 
